==> ocaml-mirage-crypto_0.10.5.orig.tar.bz2: mirage-crypto-v0.10.5/ec/native/np521_stubs.c <==
#include "mirage_crypto.h"

#ifdef ARCH_64BIT
#include "np521_64.h"
#define LIMBS 9
#define WORD uint64_t
#define WORDSIZE 64
#else
#include "np521_32.h"
#define LIMBS 17
#define WORD uint32_t
#define WORDSIZE 32
#endif

#define LEN_PRIME 521
#define CURVE_DESCRIPTION fiat_np521

#include "inversion_template.h"

#include <caml/memory.h>

CAMLprim value mc_np521_inv(value out, value in)
{
	CAMLparam2(out, in);
	inversion(Caml_ba_data_val(out), Caml_ba_data_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_mul(value out, value a, value b)
{
	CAMLparam3(out, a, b);
	fiat_np521_mul(Caml_ba_data_val(out), Caml_ba_data_val(a), Caml_ba_data_val(b));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_add(value out, value a, value b)
{
	CAMLparam3(out, a, b);
	fiat_np521_add(Caml_ba_data_val(out), Caml_ba_data_val(a), Caml_ba_data_val(b));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_one(value out)
{
	CAMLparam1(out);
	fiat_np521_set_one(Caml_ba_data_val(out));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_from_bytes(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_from_bytes(Caml_ba_data_val(out), Caml_ba_data_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_to_bytes(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_to_bytes(Caml_ba_data_val(out), Caml_ba_data_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_from_montgomery(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_from_montgomery(Caml_ba_data_val(out), Caml_ba_data_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_to_montgomery(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_to_montgomery(Caml_ba_data_val(out), Caml_ba_data_val(in));
	CAMLreturn(Val_unit);
}

==> ocaml-mirage-crypto_2.0.1.orig.tar.bz2: mirage-crypto-2.0.1/ec/native/np521_stubs.c <==
#include "mirage_crypto.h"

/* Microsoft compiler does not support 128-bit integers. Drop down to
 * 32-bit for MSVC.
 */
#if defined(ARCH_64BIT) && !defined(_MSC_VER)
#include "np521_64.h"
#define LIMBS 9
#define WORD uint64_t
#define WORDSIZE 64
#else
#include "np521_32.h"
#define LIMBS 17
#define WORD uint32_t
#define WORDSIZE 32
#endif

#define LEN_PRIME 521
#define CURVE_DESCRIPTION fiat_np521

#include "inversion_template.h"

#include <caml/memory.h>

CAMLprim value mc_np521_inv(value out, value in)
{
	CAMLparam2(out, in);
	inversion((WORD*)Bytes_val(out), (const WORD*)String_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_mul(value out, value a, value b)
{
	CAMLparam3(out, a, b);
	fiat_np521_mul((WORD*)Bytes_val(out), (const WORD*)String_val(a), (const WORD*)String_val(b));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_add(value out, value a, value b)
{
	CAMLparam3(out, a, b);
	fiat_np521_add((WORD*)Bytes_val(out), (const WORD*)String_val(a), (const WORD*)String_val(b));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_one(value out)
{
	CAMLparam1(out);
	fiat_np521_set_one((WORD*)Bytes_val(out));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_from_bytes(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_from_bytes((WORD*)Bytes_val(out), _st_uint8(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_to_bytes(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_to_bytes(Bytes_val(out), (const WORD*)String_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_from_montgomery(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_from_montgomery((WORD*)Bytes_val(out), (const WORD*)String_val(in));
	CAMLreturn(Val_unit);
}

CAMLprim value mc_np521_to_montgomery(value out, value in)
{
	CAMLparam2(out, in);
	fiat_np521_to_montgomery((WORD*)Bytes_val(out), (const WORD*)String_val(in));
	CAMLreturn(Val_unit);
}
